==> pigsty-v2.4.1.tgz: pigsty/docs/zh/SUPPORT.md <==
# 支持与订阅

Pigsty 是开箱即用的 PostgreSQL 数据库发行版，本地优先的 RDS/云数据库服务替代，让用户可以用几十块核·月的硬件成本，运行功能完备的本地RDS服务。软件本身完全开源免费，如果它帮到了您，请考虑[赞助我们](#赞助我们)。

尽管Pigsty 本身旨在用数据库自动驾驶软件替代人肉数据库运维，但再好的软件也没法解决所有的问题，总会有一些的冷门低频疑难杂症，与各种不限于技术的问题需要专家介入处理，因此我们也提供专业的[服务支持](#服务协议)。


------------------

## 赞助我们

Pigsty 本身是一个完全免费的开源软件，由 PostgreSQL 社区成员用热情浇灌而成。

如果我们的工作帮到了您，请考虑赞助或者支持一下我们的项目，一分钱也是爱，广告也是支持：

- 直接打钱赞助我们：[爱发电](https://afdian.net/a/pigsty)。
- 通过文章，讲座，视频分享您使用 Pigsty 的案例与经验。
- 允许我们在 “这些用户使用了Pigsty” 中提及您的组织。
- 向有需求的朋友，同事与客户提名/推荐我们的项目与服务。
- 关注我们的[微信公众号](https://mp.weixin.qq.com/s/-E_-HZ7LvOze5lmzy3QbQA)并转发相关技术文章至群组与朋友圈。

Pigsty社区已经提供了免费的微信群/Discord答疑服务，我们也非常乐意为支持者提供更多免费的增值服务。

微信: 搜索 `pigsty-cc` Pigsty小助手 加入 PGSQL x Pigsty 交流群

Telegram: https://t.me/joinchat/gV9zfZraNPM3YjFh

Discord: https://discord.gg/xm6hR4P4


------------------

## 服务协议

如果您有下列需求，欢迎考虑我们的专业支持服务

- 在关键场景中运行数据库，需要严格的 SLA 保障兜底。
- 希望对 Pigsty 与 PostgreSQL 相关疑难杂症提供兜底。
- 希望获取关于 PostgreSQL / Pigsty 生产环境最佳实践的指导。
- 希望有专家帮助解读监控图表，分析定位性能瓶颈与故障根因，给出意见。
- 希望根据现有资源与业务需求，规划满足安全/容灾/合规要求的数据库架构。
- 需要将其他数据库迁移至 PostgreSQL 数据库，或对历史遗留实例迁移与改造。
- 建设基于Prometheus / Grafana 技术栈的可观测性体系，数据大盘，可视化应用。
- 希望支持国产信创操作系统/国产信创 ARM 芯片架构，提供中文/本地化界面支持。
- 下云并寻求 RDS for PostgreSQL 的开源替代 —— 云中立，无供应商锁定的解决方案。
- 希望获取关于 Redis / ETCD / MinIO / Greenplum / Citus / TimescaleDB 的专业技术支持。  
- 希望规避 AGPL v3 协议对衍生作品强制使用同协议开源的的限制，进行二次开发与贴牌。
- 希望将 Pigsty 作为 SaaS/PaaS/DBaaS 对外销售，或基于此发行版提供技术服务/咨询服务。

服务订阅分为两个不同等级，**标准服务协议**与**企业级服务协议**，区别如下表所示：

|  协议/方案  |                  AGPLv3 开源协议                   |                        标准服务协议                         |                     企业级服务协议                     |
|:-------:|:----------------------------------------------:|:-----------------------------------------------------:|:-----------------------------------------------:|
|   说明    | 为遵守 AGPLv3 开源协议<br />且完全能够自给自足的<br />用户与开发者而设计 | 为那些可以基本自给自足<br />但希望得到 Pigsty 直接支持<br />与疑难杂症兜底的用户而设计 | 为需要严格的SLA的场景<br />与最大支持力度的<br />关键任务环境而设计<br /> |
| 版本支持范围  |                      当前版本                      |                    发布1年内的版本与LTS版本                     |                   发布迄今5年内的版本                    |
|  支持方式   |                    微信群公益答疑                     |              远程桌面 / 微信 <br /> 电话 / 电子邮件               |     远程桌面 / 微信 / 电话 /<br /> 电子邮件 / 现场 / 驻场*      |
| 操作系统兼容性 |                EL 7 - 9 及兼容发行版                 |                      + 信创操作系统支持                       |          + 信创操作系统支持<br />+ARM/国产芯片 支持           |
|  语言与界面  |                    English                     |                        +中文本地化                         |                     +中文本地化                      |
|   单价    |                       免费                       |          100 ¥ / 核·月 或 <br /> 1000 ¥ / 实例·月           |       200 ¥ / 核·月 或 <br /> 2000 ¥ / 实例·月        |
|  起步价格   |                                                |                     50,000 ¥ / 年                      |                  100,000 ¥ / 年                  |
|  专家人/天  |                                                |             每 20,000 ¥ 订阅费<br />附带1专家人·日              |          每 20,000 ¥ 订阅费<br />附带1专家人·日           |
|   SLA   |                                                |                      < 48 小时内响应                       |                    < 2 小时内响应                    |
| 支持时间范围  |                                                |                     8 x 5 (工作时间)                      |                  7 x 24 （全天候）                   |
| 性能/故障诊断 |                                                |                         ✅次数不限                         |                      ✅次数不限                      |
| 应急故障抢修  |                                                |                         ✅每年一次                         |                      ✅次数不限                      |
| 版本升级指导  |                                                |                         ✅每年一次                         |                      ✅次数不限                      |
| 年度架构评估  |                                                |                                                       |                      ✅每年一次                      |
| 年度性能评估  |                                                |                                                       |                      ✅每年一次                      |

* 计费使用 CPU 核数 或 实例数量作为计费依据，使用 ¥/(核·月) 作为单位，超过 10 核的实例按 10 核计算。
* 服务订阅提供中文汉化版本的监控面板，提供信创操作系统部署支持，企业级服务协议还提供国产信创芯片部署支持。
* 订阅包含数量有限的专家人天，可以用于培训，咨询，规划，升级指导，故障分析，问题排查，生产体检，教学培训。
* 正常服务支持以远程桌面/电话/微信/邮件/在线会议方式进行，现场支持需要额外收取差旅费用，标准以合同为准。
* 最终价格将视甲方团队自给自足能力，部署规模，服务范围，服务时间，服务内容等因素调整，请以合同为准。
* 我们将尽最大可能提供可行的建议与解决方案，如咨询问题未能解决，费用将酌情减免，SLA具体以合同为准。

> 参考：云数据库的报价单价通常在 ¥300 ～ ¥1300 / 核·月不等：[Vantage](https://instances.vantage.sh/)

商业支持联系方式：邮件：rh@vonng.com ， 微信 pigsty-cc / RuohangFeng


------------------

## 其他服务

我们提供零售的专家人天 可用于故障分析，问题排查，数据库体检，问题评估，教学培训，可以按需选购补充。

- 顶尖专家：20,000 ¥ / 人天 （10年以上经验的顶级数据库专家，PCM/ACE，P9+）
- 资深专家：15,000 ¥ / 人天 （5-10年经验以上的数据库专家，P8+）
- 技术专家：10,000 ¥ / 人天 （P7+）

我们提供关于 PostgreSQL 的教学与培训服务，定价如下：

- PostgreSQL 应用开发：20,000 ¥ / 1天，20人以内。
- PostgreSQL 运维管理：20,000 ¥ / 1天，20人以内。
- PostgreSQL 内核原理：35,000 ¥ / 1天，10人以内。

我们提供部署咨询与疑难杂症兜底服务，定价如下：

- 部署咨询：1000¥  / 案例，根据您现有的资源与需求为您规划部署方案。
- 中小案例：5000¥  / 案例，解决一个非紧急故障问题案例，时长不超过半个工作日，仅限远程。
- 大型案例：例如生产故障处理，数据误删恢复，价格面议。

我们提供的其他服务包括：

- 驻场DBA：仅针对大规模订阅客户提供，价格面议。
- 功能定制：数据库内核改造 / 操作系统芯片架构适配 / RDS服务OEM贴牌，价格面议。
- 项目承接：数据库系统/数据仓库建设，可观测性体系建设，数据分析/数据可视化相关，价格面议

==> pigsty-v2.5.0.tgz: pigsty/docs/zh/SUPPORT.md <==
# 支持与订阅

Pigsty 是开箱即用的 PostgreSQL 数据库发行版，本地优先的 RDS/云数据库服务替代，让用户可以用几十块核·月的硬件成本，运行功能完备的本地RDS服务。软件本身完全开源免费，如果它帮到了您，请考虑[赞助我们](#赞助我们)。

尽管Pigsty 本身旨在用数据库自动驾驶软件替代人肉数据库运维，但再好的软件也没法解决所有的问题，总会有一些的冷门低频疑难杂症，与各种不限于技术的问题需要专家介入处理，因此我们也提供专业的[服务支持](#服务协议)。


------------------

## 赞助我们

Pigsty 本身是一个完全免费的开源软件，由 PostgreSQL 社区成员用热情浇灌而成。

如果我们的工作帮到了您，请考虑赞助或者支持一下我们的项目，一分钱也是爱，广告也是支持：

- 直接打钱赞助我们：[爱发电](https://afdian.net/a/pigsty)。
- 通过文章，讲座，视频分享您使用 Pigsty 的案例与经验。
- 允许我们在 “这些用户使用了Pigsty” 中提及您的组织。
- 向有需求的朋友，同事与客户提名/推荐我们的项目与服务。
- 关注我们的[微信公众号](https://mp.weixin.qq.com/s/-E_-HZ7LvOze5lmzy3QbQA)并转发相关技术文章至群组与朋友圈。

Pigsty社区已经提供了免费的微信群/Discord答疑服务，我们也非常乐意为支持者提供更多免费的增值服务。

微信: 搜索 `pigsty-cc` Pigsty小助手 加入 PGSQL x Pigsty 交流群

Telegram: https://t.me/joinchat/gV9zfZraNPM3YjFh

Discord: https://discord.gg/Mu2b6Wxr


------------------

## 服务协议

如果您有下列需求，欢迎考虑我们的专业支持服务

- 在关键场景中运行数据库，需要严格的 SLA 保障兜底。
- 希望对 Pigsty 与 PostgreSQL 相关疑难杂症提供兜底。
- 希望获取关于 PostgreSQL / Pigsty 生产环境最佳实践的指导。
- 希望有专家帮助解读监控图表，分析定位性能瓶颈与故障根因，给出意见。
- 希望根据现有资源与业务需求，规划满足安全/容灾/合规要求的数据库架构。
- 需要将其他数据库迁移至 PostgreSQL 数据库，或对历史遗留实例迁移与改造。
- 建设基于Prometheus / Grafana 技术栈的可观测性体系，数据大盘，可视化应用。
- 希望支持国产信创操作系统/国产信创 ARM 芯片架构，提供中文/本地化界面支持。
- 下云并寻求 RDS for PostgreSQL 的开源替代 —— 云中立，无供应商锁定的解决方案。
- 希望获取关于 Redis / ETCD / MinIO / Greenplum / Citus / TimescaleDB 的专业技术支持。  
- 希望规避 AGPL v3 协议对衍生作品强制使用同协议开源的的限制，进行二次开发与贴牌。
- 希望将 Pigsty 作为 SaaS/PaaS/DBaaS 对外销售，或基于此发行版提供技术服务/咨询服务。

服务订阅分为两个不同等级，**标准服务协议**与**企业级服务协议**，区别如下表所示：

|  协议/方案  |                  AGPLv3 开源协议                   |                        标准服务协议                         |                     企业级服务协议                     |
|:-------:|:----------------------------------------------:|:-----------------------------------------------------:|:-----------------------------------------------:|
|   说明    | 为遵守 AGPLv3 开源协议<br />且完全能够自给自足的<br />用户与开发者而设计 | 为那些可以基本自给自足<br />但希望得到 Pigsty 直接支持<br />与疑难杂症兜底的用户而设计 | 为需要严格的SLA的场景<br />与最大支持力度的<br />关键任务环境而设计<br /> |
| 版本支持范围  |                      当前版本                      |                    发布1年内的版本与LTS版本                     |                   发布迄今5年内的版本                    |
|  支持方式   |                    微信群公益答疑                     |              远程桌面 / 微信 <br /> 电话 / 电子邮件               |     远程桌面 / 微信 / 电话 /<br /> 电子邮件 / 现场 / 驻场*      |
| 操作系统兼容性 |                EL 7 - 9 及兼容发行版                 |                      + 信创操作系统支持                       |          + 信创操作系统支持<br />+ARM/国产芯片 支持           |
|  语言与界面  |                    English                     |                        +中文本地化                         |                     +中文本地化                      |
|   单价    |                       免费                       |          100 ¥ / 核·月 或 <br /> 1000 ¥ / 实例·月           |       200 ¥ / 核·月 或 <br /> 2000 ¥ / 实例·月        |
|  起步价格   |                                                |                     50,000 ¥ / 年                      |                  100,000 ¥ / 年                  |
|  专家人/天  |                                                |             每 20,000 ¥ 订阅费<br />附带1专家人·日              |          每 20,000 ¥ 订阅费<br />附带1专家人·日           |
|   SLA   |                                                |                      < 48 小时内响应                       |                    < 2 小时内响应                    |
| 支持时间范围  |                                                |                     8 x 5 (工作时间)                      |                  7 x 24 （全天候）                   |
| 性能/故障诊断 |                                                |                         ✅次数不限                         |                      ✅次数不限                      |
| 应急故障抢修  |                                                |                         ✅每年一次                         |                      ✅次数不限                      |
| 版本升级指导  |                                                |                         ✅每年一次                         |                      ✅次数不限                      |
| 年度架构评估  |                                                |                                                       |                      ✅每年一次                      |
| 年度性能评估  |                                                |                                                       |                      ✅每年一次                      |

* 计费使用 CPU 核数 或 实例数量作为计费依据，使用 ¥/(核·月) 作为单位，超过 10 核的实例按 10 核计算。
* 服务订阅提供中文汉化版本的监控面板，提供信创操作系统部署支持，企业级服务协议还提供国产信创芯片部署支持。
* 订阅包含数量有限的专家人天，可以用于培训，咨询，规划，升级指导，故障分析，问题排查，生产体检，教学培训。
* 正常服务支持以远程桌面/电话/微信/邮件/在线会议方式进行，现场支持需要额外收取差旅费用，标准以合同为准。
* 最终价格将视甲方团队自给自足能力，部署规模，服务范围，服务时间，服务内容等因素调整，请以合同为准。
* 我们将尽最大可能提供可行的建议与解决方案，如咨询问题未能解决，费用将酌情减免，SLA具体以合同为准。

> 参考：云数据库的报价单价通常在 ¥300 ～ ¥1300 / 核·月不等：[Vantage](https://instances.vantage.sh/)

商业支持联系方式：邮件：rh@vonng.com ， 微信 pigsty-cc / RuohangFeng


------------------

## 其他服务

我们提供零售的专家人天 可用于故障分析，问题排查，数据库体检，问题评估，教学培训，可以按需选购补充。

- 顶尖专家：20,000 ¥ / 人天 （10年以上经验的顶级数据库专家，PCM/ACE，P9+）
- 资深专家：15,000 ¥ / 人天 （5-10年经验以上的数据库专家，P8+）
- 技术专家：10,000 ¥ / 人天 （P7+）

我们提供关于 PostgreSQL 的教学与培训服务，定价如下：

- PostgreSQL 应用开发：20,000 ¥ / 1天，20人以内。
- PostgreSQL 运维管理：20,000 ¥ / 1天，20人以内。
- PostgreSQL 内核原理：35,000 ¥ / 1天，10人以内。

我们提供部署咨询与疑难杂症兜底服务，定价如下：

- 部署咨询：1000¥  / 案例，根据您现有的资源与需求为您规划部署方案。
- 中小案例：5000¥  / 案例，解决一个非紧急故障问题案例，时长不超过半个工作日，仅限远程。
- 大型案例：例如生产故障处理，数据误删恢复，价格面议。

我们提供的其他服务包括：

- 驻场DBA：仅针对大规模订阅客户提供，价格面议。
- 功能定制：数据库内核改造 / 操作系统芯片架构适配 / RDS服务OEM贴牌，价格面议。
- 项目承接：数据库系统/数据仓库建设，可观测性体系建设，数据分析/数据可视化相关，价格面议
